%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% WordNet utilities

:- module(wn_utilities, [
  	wn_word/1,       % ?Word
  	wn_measure/1,    % ?Measure
  	check_wn_words/2 % +Words, -Word
	]
	).
	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	
	
%% wn_word(?Word)
%
%     Unifies Word with one of the words in WordNet.
%

wn_word(Word) :-
  atom(Word),
  !,
  wordnet:wn_s(_, _, Word, _, _, _).
 
wn_word(Word:Type:Sense) :-
  wordnet:wn_s(_, _, Word, Type, Sense, _).


%% wn_measure(?Measure)
%
%     Unifies Measure with one of the supported WordNet measures.
%

% wn_measure(path).
% wn_measure(wup).
% wn_measure(lch).

wn_measure(Measure) :-
  wn_gen_prox_equations:wn_measure_module_goal(Measure, _, _).


%% check_wn_words(+Words, -Word)
%
%     Return in Word the first word in the list Words which is not
%     found in WordNet. If all words are found, Word will not be 
%     unified.
%

check_wn_words([], _).

check_wn_words([Word|Words], WordNotFound) :-
  wn_word(Word),
  !,
  check_wn_words(Words, WordNotFound).
  
check_wn_words([Word|_Words], Word).

  